==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/zh_HK.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "首次使用精靈",
    "Add your profile information! For example your email is needed to receive notifications." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告及重設密碼。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照和全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照可以讓您在各種功能的界面當中快速被找到",
    "App recommendation: Calendar" : "應用程式推薦：日曆",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
    "App recommendation: Contacts" : "應用程式推薦：地址簿",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
    "App recommendation: Mail" : "應用程式推薦：郵件",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
    "App recommendation: Tasks" : "推薦功能：Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "藉由 Nextcloud 從不同裝置同步任務並且線上編輯它們。",
    "App recommendation: Deck" : "推薦功能：Deck",
    "Kanban style organization for personal planning and team projects." : "以看板風格組織您的個人計劃和團隊專案。",
    "App recommendation: Forms" : "推薦應用程式：Forms",
    "Simple surveys and questionnaires, self-hosted" : "📝 自託管的簡單調查和問卷",
    "App recommendation: Recognize" : "推薦應用程式：Recognize",
    "Smart media tagging for Nextcloud" : "Nextcloud 的智能媒體標記",
    "App recommendation: Group folders" : "推薦功能：Group folders",
    "Admin-configured folders shared by everyone in a group." : "管理員設定的資料夾，與群組中的所有人分享。",
    "App recommendation: Whiteboard" : "應用程式推薦：Whiteboard",
    "Create and share whiteboards with others and collaborate in real-time." : "建立與其他人分享白板並即時協作。",
    "Connect your calendar" : "連接您的日曆",
    "Connect your contacts" : "連接您的聯絡人",
    "Access files via WebDAV" : "透過 WebDAV 存取檔案",
    "Download macOS/iOS configuration profile" : "下載 macOS/iOS 配置檔案\n \n \n ",
    "Desktop client" : "桌面客戶端",
    "Android app on Google Play Store" : "Google Play Sore 中的 Android 應用程式",
    "Android app on F-Droid" : "F-Droid 中的 Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "About & What's new" : "關於&新功能",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的歡迎及介紹精靈",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此應用在用戶第一次登入 Nextcloud 時會開啟一個彈出式視窗。此視窗歡迎新的用戶來 Nextcloud 並且包含指引到標準桌面客戶端，Android app，及 iOS app的連結。此視窗也顯示使用 WebDAV存取 Nextcloud的連結。在任何時候，首次執行精靈可以在設定選單的\"關於\"連結再次開啟。\n首次執行精靈可以被自訂以符合特定設計目標，或是改變連結和訊息。遵照佈景主題文件建立合適的主題，並且改變此精靈外觀及感覺是很簡單。更多資訊可以在首次執行精靈文件看到，佈景主題文件也是。",
    "Download on Apple app store" : "從 Apple App Store 下載",
    "Download on Google play store" : "從 Google Play Store下載",
    "Go to previous page" : "前往上一頁",
    "Close" : "關閉",
    "More about Nextcloud" : "更多關於 Nextcloud 的資訊",
    "Explore more apps ↗" : "探索更多應用程式 ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "使用數百個社群開發的應用程式擴充 Nextcloud 的功能。",
    "Get involved! ↗" : "參與其中！ ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "成為協助建立、設計、翻譯與推廣 Nextcloud 的社群一分子！",
    "Need help? ↗" : "需要協助？ ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "透過管理員、使用者或開發者文件了解關於 Nextcloud 設定的更多資訊。",
    "For large organisations ↗" : "對於大型組織 ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "取得適用於進階安全性及法律遵循非常重要的任務關鍵型環境的 Nextcloud Enterprise。",
    "Seamless integration with your devices." : "與您的裝置無縫整合。",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "使用桌面與行動裝置應用程式在您的裝置間同步檔案，並連結您的日曆與通訊錄。",
    "Desktop app ↗" : "桌面應用程式 ↗",
    "Download For Windows, Mac OS and Linux." : "下載適用於 Windows、macOS 與 Linux 的版本",
    "Calendar and contacts ↗" : "日曆與通訊錄 ↗",
    "Connect your calendar and contacts with your devices." : "將您的日曆與通訊錄和您的裝置連結起來。",
    "Introducing Nextcloud Hub {version}" : "Nextcloud Hub {version} 簡介",
    "Welcome to {cloudName}!" : "歡迎來到 {cloudName}！",
    "This Nextcloud is on version {version}" : "此 Nextcloud 版本為 {version}",
    "A collaboration platform that puts you in control" : "一個您可掌控的協作平台",
    "Privacy" : "私隱",
    "Host your data and files where you decide." : "在您決定的位置存放您的資料與檔案。",
    "Productivity" : "生產力",
    "Collaborate and communicate across any platform." : "跨任何平台協作與溝通。",
    "Interoperability" : "互通性",
    "Import and export anything you want with open standards." : "使用開放標準匯入與匯出任何您想要的內容。",
    "Community" : "社群",
    "Enjoy constant improvements from a thriving open-source community." : "享受來自蓬勃發展的開放原始碼社群的不斷改善",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} 發布",
    "Read more about it on the Nextcloud Hub {version} blog" : "在 Nextcloud Hub {version} 部落格上了解更多相關資訊",
    "Find out more on the blog" : "在部落格上找到更多資訊",
    "Read the Nextcloud Hub {version} blog" : "閱讀 Nextcloud Hub {version} 部落格",
    "Share your opinion about Nextcloud Hub {version}" : "分享您對 Nextcloud Hub {version} 的看法",
    "Share via email" : "透過電郵分享",
    "Share on {socialMedia}" : "在 {socialMedia} 上分享",
    "New in Nextcloud Hub {version}" : "Nextcloud Hub {version} 中的新增功能",
    "Connect other apps to {productName}" : "將其他應用程式連結到 {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "除了流動裝置應用程式及桌面客戶端，您可以連結任何其他支援 WebDAV/CalDAV/CardDAV 協定的軟件到 {productName}。",
    "Apps to connect to {productName}" : "要連結到 {productName} 的應用程式",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "使用{linkStart}應用程式密碼{linkEnd}設定同步用戶端。這樣，您可以確保遺失裝置時撤銷該裝置的存取權。",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} 讓您不管身在何處都可以存取您的檔案，我們免費提供各大主要平臺上簡單易用的桌面和流動裝置客戶端",
    "App for syncing" : "用於同步的應用程式",
    "URL copied" : "已複製 URL",
    "Could not copy the URL, please copy manually" : "無法複製 URL，請手動複製",
    "Server address" : "伺服器位址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此連結來連接您的應用程式及桌面客戶端到這伺服器：",
    "End-to-end encryption in calls and web" : "通話及網頁端到端加密",
    "Performance improvements across all our products" : "改善我們所有產品的性能",
    "Thousands of tweaks for improved UX and stability" : "數以千計的調整以改善使用體驗與穩定性",
    "Your own new personal assistant" : "您的新個人小幫手",
    "Seamless file conversions" : "無縫檔案轉換",
    "Smarter team sharing with Team folders" : "使用團隊資料夾進行更聰明的團隊分享",
    "Schedule meetings directly in Talk" : "直接在 Talk 中安排會議",
    "Mail you love again: translations, summaries, and mentions" : "您將會再次愛上 Mail：翻譯、摘要與提及",
    "Get to know the new features of Hub {version}" : "了解 Hub {version} 的新功能",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 來了 – 您的模組化且統一的數碼工作空間！💫",
    "What's new?" : "有什麼新鮮事？",
    "Nextcloud on all your devices" : "您所有裝置上的 Nextcloud",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "更多",
    "Share on social media" : "在社交媒體上分享",
    "Get started!" : "開始！",
    "App recommendation: Nextcloud Calendar" : "推薦功能：Nextcloud Calendar",
    "App recommendation: Nextcloud Contacts" : "推薦功能：Nextcloud Conracts",
    "App recommendation: Nextcloud Mail" : "推薦功能：Nextcloud Mail",
    "Federated collaboration: file sharing, messaging, calls" : "聯合協作：檔案分享、訊息傳遞、通話",
    "Nextcloud Whiteboard" : "Nextcloud 白板",
    "Workflow Engine" : "工作流程引擎",
    "Safer and swifter mail" : "更安全且更迅速的電子郵件",
    "Public Collectives sharing, previews and QR-codes" : "公開收藏庫分享、預覽與 QR code",
    "Office and PDF templates" : "Office 與 PDF 範本",
    "Chat mode for Nextcloud Assistant" : "Nextcloud 小幫手的聊天模式",
    "Get to know the new features of Hub 9" : "了解 Hub 9 的新功能"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/zh_HK.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "首次使用精靈",
    "Add your profile information! For example your email is needed to receive notifications." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告及重設密碼。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照和全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照可以讓您在各種功能的界面當中快速被找到",
    "App recommendation: Calendar" : "應用程式推薦：日曆",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
    "App recommendation: Contacts" : "應用程式推薦：地址簿",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
    "App recommendation: Mail" : "應用程式推薦：郵件",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
    "App recommendation: Tasks" : "推薦功能：Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "藉由 Nextcloud 從不同裝置同步任務並且線上編輯它們。",
    "App recommendation: Deck" : "推薦功能：Deck",
    "Kanban style organization for personal planning and team projects." : "以看板風格組織您的個人計劃和團隊專案。",
    "App recommendation: Forms" : "推薦應用程式：Forms",
    "Simple surveys and questionnaires, self-hosted" : "📝 自託管的簡單調查和問卷",
    "App recommendation: Recognize" : "推薦應用程式：Recognize",
    "Smart media tagging for Nextcloud" : "Nextcloud 的智能媒體標記",
    "App recommendation: Group folders" : "推薦功能：Group folders",
    "Admin-configured folders shared by everyone in a group." : "管理員設定的資料夾，與群組中的所有人分享。",
    "App recommendation: Whiteboard" : "應用程式推薦：Whiteboard",
    "Create and share whiteboards with others and collaborate in real-time." : "建立與其他人分享白板並即時協作。",
    "Connect your calendar" : "連接您的日曆",
    "Connect your contacts" : "連接您的聯絡人",
    "Access files via WebDAV" : "透過 WebDAV 存取檔案",
    "Download macOS/iOS configuration profile" : "下載 macOS/iOS 配置檔案\n \n \n ",
    "Desktop client" : "桌面客戶端",
    "Android app on Google Play Store" : "Google Play Sore 中的 Android 應用程式",
    "Android app on F-Droid" : "F-Droid 中的 Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "About & What's new" : "關於&新功能",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的歡迎及介紹精靈",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此應用在用戶第一次登入 Nextcloud 時會開啟一個彈出式視窗。此視窗歡迎新的用戶來 Nextcloud 並且包含指引到標準桌面客戶端，Android app，及 iOS app的連結。此視窗也顯示使用 WebDAV存取 Nextcloud的連結。在任何時候，首次執行精靈可以在設定選單的\"關於\"連結再次開啟。\n首次執行精靈可以被自訂以符合特定設計目標，或是改變連結和訊息。遵照佈景主題文件建立合適的主題，並且改變此精靈外觀及感覺是很簡單。更多資訊可以在首次執行精靈文件看到，佈景主題文件也是。",
    "Download on Apple app store" : "從 Apple App Store 下載",
    "Download on Google play store" : "從 Google Play Store下載",
    "Go to previous page" : "前往上一頁",
    "Close" : "關閉",
    "More about Nextcloud" : "更多關於 Nextcloud 的資訊",
    "Explore more apps ↗" : "探索更多應用程式 ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "使用數百個社群開發的應用程式擴充 Nextcloud 的功能。",
    "Get involved! ↗" : "參與其中！ ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "成為協助建立、設計、翻譯與推廣 Nextcloud 的社群一分子！",
    "Need help? ↗" : "需要協助？ ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "透過管理員、使用者或開發者文件了解關於 Nextcloud 設定的更多資訊。",
    "For large organisations ↗" : "對於大型組織 ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "取得適用於進階安全性及法律遵循非常重要的任務關鍵型環境的 Nextcloud Enterprise。",
    "Seamless integration with your devices." : "與您的裝置無縫整合。",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "使用桌面與行動裝置應用程式在您的裝置間同步檔案，並連結您的日曆與通訊錄。",
    "Desktop app ↗" : "桌面應用程式 ↗",
    "Download For Windows, Mac OS and Linux." : "下載適用於 Windows、macOS 與 Linux 的版本",
    "Calendar and contacts ↗" : "日曆與通訊錄 ↗",
    "Connect your calendar and contacts with your devices." : "將您的日曆與通訊錄和您的裝置連結起來。",
    "Introducing Nextcloud Hub {version}" : "Nextcloud Hub {version} 簡介",
    "Welcome to {cloudName}!" : "歡迎來到 {cloudName}！",
    "This Nextcloud is on version {version}" : "此 Nextcloud 版本為 {version}",
    "A collaboration platform that puts you in control" : "一個您可掌控的協作平台",
    "Privacy" : "私隱",
    "Host your data and files where you decide." : "在您決定的位置存放您的資料與檔案。",
    "Productivity" : "生產力",
    "Collaborate and communicate across any platform." : "跨任何平台協作與溝通。",
    "Interoperability" : "互通性",
    "Import and export anything you want with open standards." : "使用開放標準匯入與匯出任何您想要的內容。",
    "Community" : "社群",
    "Enjoy constant improvements from a thriving open-source community." : "享受來自蓬勃發展的開放原始碼社群的不斷改善",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} 發布",
    "Read more about it on the Nextcloud Hub {version} blog" : "在 Nextcloud Hub {version} 部落格上了解更多相關資訊",
    "Find out more on the blog" : "在部落格上找到更多資訊",
    "Read the Nextcloud Hub {version} blog" : "閱讀 Nextcloud Hub {version} 部落格",
    "Share your opinion about Nextcloud Hub {version}" : "分享您對 Nextcloud Hub {version} 的看法",
    "Share via email" : "透過電郵分享",
    "Share on {socialMedia}" : "在 {socialMedia} 上分享",
    "New in Nextcloud Hub {version}" : "Nextcloud Hub {version} 中的新增功能",
    "Connect other apps to {productName}" : "將其他應用程式連結到 {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "除了流動裝置應用程式及桌面客戶端，您可以連結任何其他支援 WebDAV/CalDAV/CardDAV 協定的軟件到 {productName}。",
    "Apps to connect to {productName}" : "要連結到 {productName} 的應用程式",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "使用{linkStart}應用程式密碼{linkEnd}設定同步用戶端。這樣，您可以確保遺失裝置時撤銷該裝置的存取權。",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} 讓您不管身在何處都可以存取您的檔案，我們免費提供各大主要平臺上簡單易用的桌面和流動裝置客戶端",
    "App for syncing" : "用於同步的應用程式",
    "URL copied" : "已複製 URL",
    "Could not copy the URL, please copy manually" : "無法複製 URL，請手動複製",
    "Server address" : "伺服器位址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此連結來連接您的應用程式及桌面客戶端到這伺服器：",
    "Global redesign and usability lift" : "全面重新設計與可用性提升",
    "New Office UI: colors, tabs, bars" : "新的 Office 使用者介面：色彩、分頁、工具列",
    "Performance and stability boost" : "效能與穩定性提昇",
    "New AI Agency tools unlocked" : "已解鎖全新的人工智慧代理工具",
    "Talk threads & live transcription" : "Talk 討論串與即時轉錄",
    "Calendar: date poll for participants" : "日曆：參與者的日期投票",
    "Intuitive file search" : "直觀檔案搜尋",
    "Teams 2.0 & quick Guest accounts" : "團隊 2.0 與快速訪客帳號",
    "Quick presets & many other admin updates" : "快速預設組合及更多其他管理員更新",
    "Vue3, WebSockets and more OpenAPI for devs" : "Vue3、WebSockets 及更多供開發者使用的 OpenAPI",
    "… and much more!" : "… 還有更多！",
    "Get to know the new features of Hub {version}" : "了解 Hub {version} 的新功能",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 Autumn – 您的數位工作空間，即刻啟程 ⚡",
    "What's new?" : "有什麼新鮮事？",
    "Nextcloud on all your devices" : "您所有裝置上的 Nextcloud",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "更多",
    "Share on social media" : "在社交媒體上分享",
    "Get started!" : "開始！",
    "End-to-end encryption in calls and web" : "通話及網頁端到端加密",
    "Performance improvements across all our products" : "改善我們所有產品的性能",
    "Thousands of tweaks for improved UX and stability" : "數以千計的調整以改善使用體驗與穩定性",
    "Your own new personal assistant" : "您的新個人小幫手",
    "Seamless file conversions" : "無縫檔案轉換",
    "Smarter team sharing with Team folders" : "使用團隊資料夾進行更聰明的團隊分享",
    "Schedule meetings directly in Talk" : "直接在 Talk 中安排會議",
    "Mail you love again: translations, summaries, and mentions" : "您將會再次愛上 Mail：翻譯、摘要與提及",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 來了 – 您的模組化且統一的數碼工作空間！💫"
},
"nplurals=1; plural=0;");
